=====
Nimoy
=====
A testing and specification framework for Python 3, heavily inspired by the amazing Spock_ Framework.

.. _Spock: http://spockframework.org

Features 
--------
- Based on ``unittest``, so minimal dependencies are required and specifications are recognized by IDEs and report analyzers.
- Reduction of boilerplate code.
- Write detailed specifications with clear distinction.
- Auto discovery of specifications.
- Write data-driven specifications.
- Pretty mock behavior assertion.
- See fancy detailed assertion failure reports.

License
-------
Apache License 2.0

In memory of Leonard Nimoy 1931-2015
------------------------------------
